@@ -8,7 +8,7 @@ use vars qw($VERSION @ISA @EXPORT_OK);
 
 use XML::DT;
 
-$VERSION = '0.2';
+$VERSION = '0.1';
 @ISA = 'Exporter';
 @EXPORT_OK = qw();
 
@@ -23,18 +23,11 @@ sub new {
 
   my $self = {
 	      filename => $file,
-	      ignore_markup => 1,
 	     };
 
   return bless $self, $class;
 }
 
-sub ignore_markup {
-  my $self = shift;
-  my $opt = shift || 1;
-  $self->{ignore_markup} = $opt;
-}
-
 sub languages {
   my $self = shift;
   my %languages = ();
@@ -49,43 +42,15 @@ sub for_tu {
   my %handler = ( -type => { tu => 'SEQ' },
 		  tu  => sub {
 		    my %tu = map { ( $_->[0] => $_->[1] ) } @$c;
-		    &{$code}(\%tu,\%v);
+		    &{$code}(\%tu);
 		  },
-		  tuv => sub { [$v{lang} || $v{'xml:lang'}, $c] },
+		  tuv => sub { [$v{lang}, $c] },
 		  seg => sub { $c },
-		  body => sub { $c },
-		  tmx => sub { $c },
-		  hi => sub { $self->{ignore_markup}?$c:toxml },
-		  ph => sub { $self->{ignore_markup}?$c:toxml },
 		);
 
   dt($self->{filename}, %handler);
 }
 
-sub to_html {
-  my $self = shift;
-  my %opt = @_;
-  $self->for_tu(sub {
-		  my ($langs, $opts) = @_;
-		  my $ret = "<table>";
-		  for (keys %$langs) {
-		    $ret .= "<tr><td style=\"vertical-align: top\">";
-		    if ($opt{icons}) {
-		      $ret .= "<img src=\"/icons/flags/".lc($_).".png\" alt=\"$_\"/>"
-		    } else {
-		      $ret .= "$_"
-		    }
-		    $ret .= "</td><td>$langs->{$_}</td></tr>\n"
-		  }
-		  $ret .= "<tr><td></td><td><div style=\"font-size: small; color: #999;\">";
-		  for (keys %$opts) {
-		    $ret .= "$_: $opts->{$_} &nbsp;&nbsp; "
-		  }
-		  $ret .= "</div></td></tr></table>";
-		  $ret;
-		});
-}
-
 =head1 NAME
 
 XML::TMX::Reader - Perl extension for reading TMX files
